/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2013 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *   Main Developers:                                                     *
 *       Eric MAEKER, MD <eric.maeker@gmail.com>                           *
 *  Contributors:                                                          *
 *       NAME <MAIL@ADDRESS.COM>                                           *
 ***************************************************************************/
#ifndef DATAPACK_LOCALSERVERENGINE_H
#define DATAPACK_LOCALSERVERENGINE_H

#include <datapackutils/iserverengine.h>

namespace DataPack {
namespace Internal {
class ServerManager;

class LocalServerEngine : public IServerEngine
{
    Q_OBJECT
public:
    LocalServerEngine(QObject *parent);

    bool managesServer(const Server &server);
    void addToDownloadQueue(const ServerEngineQuery &query);
    int downloadQueueCount() const;
    bool startDownloadQueue();

    int runningJobs() const;
    bool stopJobsAndClearQueue();

    const ServerEngineStatus &lastStatus(const Pack &pack);
    const ServerEngineStatus &lastStatus(const Server &server);

private Q_SLOTS:
    void emitQueueDowloaded();

private:
    QList<ServerEngineQuery> m_queue;
    QHash<QString, ServerEngineStatus> m_ServerStatus, m_PackStatus;
};

} // namespace Internal
} // namespace DataPack

#endif // DATAPACK_LOCALSERVERENGINE_H
